/* eslint-disable*/
import React, { useState } from 'react';
import { Form, Input, Button, Space, Select } from 'antd';
import { MinusCircleOutlined, PlusOutlined } from '@ant-design/icons';
import { get, post } from 'services';

const methods = [
  { label: 'get', value: 'get' },
  { label: 'post', value: 'post' },
];

const RequestTest = () => {
  const [protocal, setprotocal] = useState('http://');
  const [form] = Form.useForm();

  const onFinish = values => {
    const url = protocal + values.url;
    const methodMap = { get, post };
    const { method } = values;
    const params =
      values.params &&
      values.params.reduce((param, { key, value }) => {
        param[key.trim()] = value.trim();
        return param;
      }, {});
    if (window.location.host === values.url) {
      methodMap[method](url, params).catch(err => {
          console.error(err);
        });
    } else {
      get('/setproxy', { host: url.match(/^(https?:\/\/[^\/]+)/)[1] }).then(
        res => {
          const proxyUrl = url.replace(/^https?:\/\/([^\/]+)/, $1 => {
            return `${window.location.origin}`;
          });
          methodMap[method](proxyUrl, params)
            .catch(err => {
              console.error(err);
            });
        },
      );
    }
  };

  const handleProtoSelectChange = v => {
    setprotocal(v);
  };

  const handleKeyChange = (v, field) => {
    console.log(form);
  };
  const handleValueChange = (v, field) => {
    console.log(form);
  };

  const protocalBefore = (
    <Select
      defaultValue="http://"
      className="select-before"
      onChange={handleProtoSelectChange}
    >
      <Option value="http://">http://</Option>
      <Option value="https://">https://</Option>
    </Select>
  );

  return (
    <Form
      form={form}
      name="dynamic_form_nest_item"
      onFinish={onFinish}
      autoComplete="off"
    >
      <Form.Item
        name="url"
        label="url"
        rules={[{ required: true, message: 'Missing url' }]}
        initialValue={window.location.host}
      >
        <Input addonBefore={protocalBefore} />
      </Form.Item>
      <Form.Item
        name="method"
        label="method"
        rules={[{ required: true, message: 'Missing method' }]}
        initialValue="get"
      >
        <Select options={methods} />
      </Form.Item>
      <Form.List name="params">
        {(fields, { add, remove }) => {
          return (
            <>
              {fields.map(field => (
                <Space key={field.key} align="start">
                  <Form.Item
                    {...field}
                    label={`key`}
                    name={[field.name, 'key']}
                    fieldKey={[field.fieldKey, 'key']}
                    rules={[{ required: true, message: 'Missing key' }]}
                  >
                    <Input onChange={v => handleKeyChange(v, field)} />
                  </Form.Item>
                  <Form.Item
                    {...field}
                    label={`value`}
                    fieldKey={[field.fieldKey, 'value']}
                    name={[field.name, 'value']}
                  >
                    <Input onChange={v => handleValueChange(v, field)} />
                  </Form.Item>
                  <MinusCircleOutlined
                    onClick={() => console.log(field) || remove(field.name)}
                  />
                </Space>
              ))}
              <Form.Item>
                <Button
                  type="dashed"
                  onClick={() => {
                    add();
                  }}
                  block
                >
                  <PlusOutlined /> Add params
                </Button>
              </Form.Item>
            </>
          );
        }}
      </Form.List>

      <Form.Item>
        <Button type="primary" htmlType="submit">
          Submit
        </Button>
      </Form.Item>
    </Form>
  );
};

export default RequestTest;
